@@ -1,7 +1,7 @@
 from django.conf import settings
 from django.urls import path, re_path
 
-from wspay.views import ProcessView, ProcessResponseView, TestView
+from wspay.views import ProcessView, ProcessResponseView, TestView, TransactionReportView
 
 app_name = 'wspay'
 
@@ -16,6 +16,11 @@ urlpatterns = [
         ProcessResponseView.as_view(),
         name='process-response'
     ),
+    path(
+        'transaction-report/',
+        TransactionReportView.as_view(),
+        name='transaction-report'
+    ),
 ]
 
 if settings.DEBUG:
